==> netdata-2.5.3.tar.gz: netdata-v2.5.3/docs/Demo-Sites.md <==

# Live demos

See the live Netdata Cloud demo with Rooms (listed below) for specific use cases at `https://app.netdata.cloud/spaces/netdata-demo`

| Location            | Netdata Demo URL                                                                                                                                | 60 mins reqs                                                                                                                                                                                                                                                 | VM donated by                                      |
|:--------------------|:------------------------------------------------------------------------------------------------------------------------------------------------|:-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|:---------------------------------------------------|
| Netdata Cloud       | **[Netdata Demo - All nodes](https://app.netdata.cloud/spaces/netdata-demo/rooms/all-nodes/overview)**                                          |                                                                                                                                                                                                                                                              |                                                    |
| Netdata Cloud       | **[Netdata Demo - Active Directory](https://app.netdata.cloud/spaces/netdata-demo/rooms/active-directory/overview)**                            |                                                                                                                                                                                                                                                              |                                                    |
| Netdata Cloud       | **[Netdata Demo - Apache](https://app.netdata.cloud/spaces/netdata-demo/rooms/apache/overview)**                                                |                                                                                                                                                                                                                                                              |                                                    |
| Netdata Cloud       | **[Netdata Demo - Cassandra](https://app.netdata.cloud/spaces/netdata-demo/rooms/cassandra/overview)**                                          |                                                                                                                                                                                                                                                              |                                                    |
| Netdata Cloud       | **[Netdata Demo - CoreDNS](https://app.netdata.cloud/spaces/netdata-demo/rooms/coredns/overview)**                                              |                                                                                                                                                                                                                                                              |                                                    |
| Netdata Cloud       | **[Netdata Demo - DNS Query](https://app.netdata.cloud/spaces/netdata-demo/rooms/dns-query/overview)**                                          |                                                                                                                                                                                                                                                              |                                                    |
| Netdata Cloud       | **[Netdata Demo - Docker](https://app.netdata.cloud/spaces/netdata-demo/rooms/docker/overview)**                                                |                                                                                                                                                                                                                                                              |                                                    |
| Netdata Cloud       | **[Netdata Demo - Host Reachability](https://app.netdata.cloud/spaces/netdata-demo/rooms/host-reachability/overview)**                          |                                                                                                                                                                                                                                                              |                                                    |
| Netdata Cloud       | **[Netdata Demo - HTTP Endpoints](https://app.netdata.cloud/spaces/netdata-demo/rooms/http-endpoints/overview)**                                |                                                                                                                                                                                                                                                              |                                                    |
| Netdata Cloud       | **[Netdata Demo - IIS](https://app.netdata.cloud/spaces/netdata-demo/rooms/iis/overview)**                                                      |                                                                                                                                                                                                                                                              |                                                    |
| Netdata Cloud       | **[Netdata Demo - Kubernetes](https://app.netdata.cloud/spaces/netdata-demo/rooms/kubernetes/kubernetes)**                                      |                                                                                                                                                                                                                                                              |                                                    |
| Netdata Cloud       | **[Netdata Demo - Machine Learning](https://app.netdata.cloud/spaces/netdata-demo/rooms/machine-learning/overview)**                            |                                                                                                                                                                                                                                                              |                                                    |
| Netdata Cloud       | **[Netdata Demo - MS Exchange](https://app.netdata.cloud/spaces/netdata-demo/rooms/ms-exchange/overview)**                                      |                                                                                                                                                                                                                                                              |                                                    |
| Netdata Cloud       | **[Netdata Demo - Nginx](https://app.netdata.cloud/spaces/netdata-demo/rooms/nginx/overview)**                                                  |                                                                                                                                                                                                                                                              |                                                    |
| Netdata Cloud       | **[Netdata Demo - PostgreSQL](https://app.netdata.cloud/spaces/netdata-demo/rooms/postgresql/overview)**                                        |                                                                                                                                                                                                                                                              |                                                    |
| Netdata Cloud       | **[Netdata Demo - Redis](https://app.netdata.cloud/spaces/netdata-demo/rooms/redis/overview)**                                                  |                                                                                                                                                                                                                                                              |                                                    |
| Netdata Cloud       | **[Netdata Demo - Windows](https://app.netdata.cloud/spaces/netdata-demo/rooms/windows/overview)**                                              |                                                                                                                                                                                                                                                              |                                                    |
| London (UK)         | **[london3.my-netdata.io](https://london3.my-netdata.io)**<br/>(this is the global Netdata **registry** and has **named** and **mysql** charts) | [![Requests Per Second](https://london3.my-netdata.io/api/v1/badge.svg?chart=netdata.requests&dimensions=requests&after=-3600&options=unaligned&group=sum&label=reqs&units=empty&value_color=blue&precision=0&v42)](https://london3.my-netdata.io)           | [DigitalOcean.com](https://m.do.co/c/83dc9f941745) |
| Atlanta (USA)       | **[cdn77.my-netdata.io](https://cdn77.my-netdata.io)**<br/>(with **named** and **mysql** charts)                                                | [![Requests Per Second](https://cdn77.my-netdata.io/api/v1/badge.svg?chart=netdata.requests&dimensions=requests&after=-3600&options=unaligned&group=sum&label=reqs&units=empty&value_color=blue&precision=0&v42)](https://cdn77.my-netdata.io)               | [CDN77.com](https://www.cdn77.com/)                |
| Bangalore (India)   | **[bangalore.my-netdata.io](https://bangalore.my-netdata.io)**                                                                                  | [![Requests Per Second](https://bangalore.my-netdata.io/api/v1/badge.svg?chart=netdata.requests&dimensions=requests&after=-3600&options=unaligned&group=sum&label=reqs&units=empty&value_color=blue&precision=0&v42)](https://bangalore.my-netdata.io)       | [DigitalOcean.com](https://m.do.co/c/83dc9f941745) |
| Frankfurt (Germany) | **[frankfurt.my-netdata.io](https://frankfurt.my-netdata.io)**                                                                                  | [![Requests Per Second](https://frankfurt.my-netdata.io/api/v1/badge.svg?chart=netdata.requests&dimensions=requests&after=-3600&options=unaligned&group=sum&label=reqs&units=empty&value_color=blue&precision=0&v42)](https://frankfurt.my-netdata.io)       | [DigitalOcean.com](https://m.do.co/c/83dc9f941745) |
| New York (USA)      | **[newyork.my-netdata.io](https://newyork.my-netdata.io)**                                                                                      | [![Requests Per Second](https://newyork.my-netdata.io/api/v1/badge.svg?chart=netdata.requests&dimensions=requests&after=-3600&options=unaligned&group=sum&label=reqs&units=empty&value_color=blue&precision=0&v42)](https://newyork.my-netdata.io)           | [DigitalOcean.com](https://m.do.co/c/83dc9f941745) |
| San Francisco (USA) | **[sanfrancisco.my-netdata.io](https://sanfrancisco.my-netdata.io)**                                                                            | [![Requests Per Second](https://sanfrancisco.my-netdata.io/api/v1/badge.svg?chart=netdata.requests&dimensions=requests&after=-3600&options=unaligned&group=sum&label=reqs&units=empty&value_color=blue&precision=0&v42)](https://sanfrancisco.my-netdata.io) | [DigitalOcean.com](https://m.do.co/c/83dc9f941745) |
| Singapore           | **[singapore.my-netdata.io](https://singapore.my-netdata.io)**                                                                                  | [![Requests Per Second](https://singapore.my-netdata.io/api/v1/badge.svg?chart=netdata.requests&dimensions=requests&after=-3600&options=unaligned&group=sum&label=reqs&units=empty&value_color=blue&precision=0&v42)](https://singapore.my-netdata.io)       | [DigitalOcean.com](https://m.do.co/c/83dc9f941745) |
| Toronto (Canada)    | **[toronto.my-netdata.io](https://toronto.my-netdata.io)**                                                                                      | [![Requests Per Second](https://toronto.my-netdata.io/api/v1/badge.svg?chart=netdata.requests&dimensions=requests&after=-3600&options=unaligned&group=sum&label=reqs&units=empty&value_color=blue&precision=0&v42)](https://toronto.my-netdata.io)           | [DigitalOcean.com](https://m.do.co/c/83dc9f941745) |

Netdata dashboards are mobile- and touch-friendly.

==> netdata-v2.8.1.tar.gz: netdata-v2.8.1/docs/Demo-Sites.md <==

# Live demos

See the live Netdata Cloud demo with Rooms (listed below) for specific use cases at [`https://app.netdata.cloud/spaces/netdata-demo`](https://app.netdata.cloud/spaces/netdata-demo)

| Location            | Netdata Demo URL                                                                                                                                | 60 mins reqs                                                                                                                                                                                                                                                 | VM donated by                                      |
|:--------------------|:------------------------------------------------------------------------------------------------------------------------------------------------|:-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|:---------------------------------------------------|
| Netdata Cloud       | **[Netdata Demo - All nodes](https://app.netdata.cloud/spaces/netdata-demo/rooms/all-nodes/overview)**                                          |                                                                                                                                                                                                                                                              |                                                    |
| Netdata Cloud       | **[Netdata Demo - Active Directory](https://app.netdata.cloud/spaces/netdata-demo/rooms/active-directory/overview)**                            |                                                                                                                                                                                                                                                              |                                                    |
| Netdata Cloud       | **[Netdata Demo - Apache](https://app.netdata.cloud/spaces/netdata-demo/rooms/apache/overview)**                                                |                                                                                                                                                                                                                                                              |                                                    |
| Netdata Cloud       | **[Netdata Demo - Cassandra](https://app.netdata.cloud/spaces/netdata-demo/rooms/cassandra/overview)**                                          |                                                                                                                                                                                                                                                              |                                                    |
| Netdata Cloud       | **[Netdata Demo - CoreDNS](https://app.netdata.cloud/spaces/netdata-demo/rooms/coredns/overview)**                                              |                                                                                                                                                                                                                                                              |                                                    |
| Netdata Cloud       | **[Netdata Demo - DNS Query](https://app.netdata.cloud/spaces/netdata-demo/rooms/dns-query/overview)**                                          |                                                                                                                                                                                                                                                              |                                                    |
| Netdata Cloud       | **[Netdata Demo - Docker](https://app.netdata.cloud/spaces/netdata-demo/rooms/docker/overview)**                                                |                                                                                                                                                                                                                                                              |                                                    |
| Netdata Cloud       | **[Netdata Demo - Host Reachability](https://app.netdata.cloud/spaces/netdata-demo/rooms/host-reachability/overview)**                          |                                                                                                                                                                                                                                                              |                                                    |
| Netdata Cloud       | **[Netdata Demo - HTTP Endpoints](https://app.netdata.cloud/spaces/netdata-demo/rooms/http-endpoints/overview)**                                |                                                                                                                                                                                                                                                              |                                                    |
| Netdata Cloud       | **[Netdata Demo - IIS](https://app.netdata.cloud/spaces/netdata-demo/rooms/iis/overview)**                                                      |                                                                                                                                                                                                                                                              |                                                    |
| Netdata Cloud       | **[Netdata Demo - Kubernetes](https://app.netdata.cloud/spaces/netdata-demo/rooms/kubernetes/kubernetes)**                                      |                                                                                                                                                                                                                                                              |                                                    |
| Netdata Cloud       | **[Netdata Demo - Machine Learning](https://app.netdata.cloud/spaces/netdata-demo/rooms/machine-learning/overview)**                            |                                                                                                                                                                                                                                                              |                                                    |
| Netdata Cloud       | **[Netdata Demo - MS Exchange](https://app.netdata.cloud/spaces/netdata-demo/rooms/ms-exchange/overview)**                                      |                                                                                                                                                                                                                                                              |                                                    |
| Netdata Cloud       | **[Netdata Demo - Nginx](https://app.netdata.cloud/spaces/netdata-demo/rooms/nginx/overview)**                                                  |                                                                                                                                                                                                                                                              |                                                    |
| Netdata Cloud       | **[Netdata Demo - PostgreSQL](https://app.netdata.cloud/spaces/netdata-demo/rooms/postgresql/overview)**                                        |                                                                                                                                                                                                                                                              |                                                    |
| Netdata Cloud       | **[Netdata Demo - Redis](https://app.netdata.cloud/spaces/netdata-demo/rooms/redis/overview)**                                                  |                                                                                                                                                                                                                                                              |                                                    |
| Netdata Cloud       | **[Netdata Demo - Windows](https://app.netdata.cloud/spaces/netdata-demo/rooms/windows/overview)**                                              |                                                                                                                                                                                                                                                              |                                                    |
| London (UK)         | **[london3.my-netdata.io](https://london3.my-netdata.io)**<br/>(this is the global Netdata **registry** and has **named** and **mysql** charts) | [![Requests Per Second](https://london3.my-netdata.io/api/v1/badge.svg?chart=netdata.requests&dimensions=requests&after=-3600&options=unaligned&group=sum&label=reqs&units=empty&value_color=blue&precision=0&v42)](https://london3.my-netdata.io)           | [DigitalOcean.com](https://m.do.co/c/83dc9f941745) |
| Atlanta (USA)       | **[cdn77.my-netdata.io](https://cdn77.my-netdata.io)**<br/>(with **named** and **mysql** charts)                                                | [![Requests Per Second](https://cdn77.my-netdata.io/api/v1/badge.svg?chart=netdata.requests&dimensions=requests&after=-3600&options=unaligned&group=sum&label=reqs&units=empty&value_color=blue&precision=0&v42)](https://cdn77.my-netdata.io)               | [CDN77.com](https://www.cdn77.com/)                |
| Bangalore (India)   | **[bangalore.my-netdata.io](https://bangalore.my-netdata.io)**                                                                                  | [![Requests Per Second](https://bangalore.my-netdata.io/api/v1/badge.svg?chart=netdata.requests&dimensions=requests&after=-3600&options=unaligned&group=sum&label=reqs&units=empty&value_color=blue&precision=0&v42)](https://bangalore.my-netdata.io)       | [DigitalOcean.com](https://m.do.co/c/83dc9f941745) |
| Frankfurt (Germany) | **[frankfurt.my-netdata.io](https://frankfurt.my-netdata.io)**                                                                                  | [![Requests Per Second](https://frankfurt.my-netdata.io/api/v1/badge.svg?chart=netdata.requests&dimensions=requests&after=-3600&options=unaligned&group=sum&label=reqs&units=empty&value_color=blue&precision=0&v42)](https://frankfurt.my-netdata.io)       | [DigitalOcean.com](https://m.do.co/c/83dc9f941745) |
| New York (USA)      | **[newyork.my-netdata.io](https://newyork.my-netdata.io)**                                                                                      | [![Requests Per Second](https://newyork.my-netdata.io/api/v1/badge.svg?chart=netdata.requests&dimensions=requests&after=-3600&options=unaligned&group=sum&label=reqs&units=empty&value_color=blue&precision=0&v42)](https://newyork.my-netdata.io)           | [DigitalOcean.com](https://m.do.co/c/83dc9f941745) |
| San Francisco (USA) | **[sanfrancisco.my-netdata.io](https://sanfrancisco.my-netdata.io)**                                                                            | [![Requests Per Second](https://sanfrancisco.my-netdata.io/api/v1/badge.svg?chart=netdata.requests&dimensions=requests&after=-3600&options=unaligned&group=sum&label=reqs&units=empty&value_color=blue&precision=0&v42)](https://sanfrancisco.my-netdata.io) | [DigitalOcean.com](https://m.do.co/c/83dc9f941745) |
| Singapore           | **[singapore.my-netdata.io](https://singapore.my-netdata.io)**                                                                                  | [![Requests Per Second](https://singapore.my-netdata.io/api/v1/badge.svg?chart=netdata.requests&dimensions=requests&after=-3600&options=unaligned&group=sum&label=reqs&units=empty&value_color=blue&precision=0&v42)](https://singapore.my-netdata.io)       | [DigitalOcean.com](https://m.do.co/c/83dc9f941745) |
| Toronto (Canada)    | **[toronto.my-netdata.io](https://toronto.my-netdata.io)**                                                                                      | [![Requests Per Second](https://toronto.my-netdata.io/api/v1/badge.svg?chart=netdata.requests&dimensions=requests&after=-3600&options=unaligned&group=sum&label=reqs&units=empty&value_color=blue&precision=0&v42)](https://toronto.my-netdata.io)           | [DigitalOcean.com](https://m.do.co/c/83dc9f941745) |

Netdata dashboards are mobile- and touch-friendly.
